summaryrefslogtreecommitdiffstats
path: root/krdc/vnc/rfbproto.c
diff options
context:
space:
mode:
Diffstat (limited to 'krdc/vnc/rfbproto.c')
-rw-r--r--krdc/vnc/rfbproto.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/krdc/vnc/rfbproto.c b/krdc/vnc/rfbproto.c
index 13676bb6..8424e6ac 100644
--- a/krdc/vnc/rfbproto.c
+++ b/krdc/vnc/rfbproto.c
@@ -159,7 +159,7 @@ ConnectToRFBServer(const char *hostname, int port)
* InitialiseRFBConnection.
*/
-enum InittqStatus
+enum InitStatus
InitialiseRFBConnection()
{
rfbProtocolVersionMsg pv;
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
/*********************************************************************
* HandletqCursorShape(). Support for XCursor and RichCursor tqshape
* updates. We emulate cursor operating on the frame buffer (that is
* why we call it "software cursor").
********************************************************************/
-static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
+static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
{
int bytesPerPixel;
size_t bytesPerRow, bytesMaskData;
@@ -956,7 +956,7 @@ HandleRFBServerMessage()
if (rect.encoding == rfbEncodingXCursor ||
rect.encoding == rfbEncodingRichCursor) {
- if (!HandletqCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
+ if (!HandleCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
rect.encoding)) {
return False;
}
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
/*********************************************************************
- * HandletqCursorShape(). Support for XCursor and RichCursor tqshape
+ * HandleCursorShape(). Support for XCursor and RichCursor shape
* updates. We emulate cursor operating on the frame buffer (that is
* why we call it "software cursor").